/*==============================================================================
This file replicates Figure 1 of the JMCB paper
"Countercyclical Capital Buffers: A Cautionary Tale" by

Christoffer Koch (International Monetary Fund)
Gary Richardon (UC Irvine)
Patrick Van Horn (Scripps College)

==============================================================================*/

set varabbrev off
version 15.1
clear all 
use "./data/Figure1_Banking_Monetary_Statistics.dta", replace

qui generate mofd=mofd(Call_Date_stata_format)
format mofd %tm
tsset mofd

format %tdCCYY Call_Date_stata_format
label var r_leverage "Reserve Cities"
label var c_leverage "Chicago"
label var n_leverage "New York"
label var Call_Date_stata_format "Date of Call"

qui generate n_capratio = 1/n_leverage
qui generate c_capratio = 1/c_leverage
qui generate r_capratio = 1/r_leverage

label var r_capratio "Reserve Cities"
label var c_capratio "Chicago"
label var n_capratio "New York"
label var mofd "Month of Call"

qui replace n_capratio = 100*n_capratio
qui replace c_capratio = 100*c_capratio
qui replace r_capratio = 100*r_capratio

// for t-labels ...
di td(1jan1920)
di td(1jan1921)
di td(1jan1922)
di td(1jan1923)
di td(1jan1924)
di td(1jan1925)
di td(1jan1926)
di td(1jan1927)
di td(1jan1928)
di td(1jan1929)
di td(1jan1930)
di td(1jan1931)
di td(1jan1932)
di td(1jan1933)
di td(1jul1927)

#delimit
twoway 
	(lpoly   n_capratio Call_Date_stata_format, lc(black) lw(medthick) lp(solid))
	(lpoly   c_capratio Call_Date_stata_format, lc(black) lw(medthick) lp(dot)) 
	(lpoly   r_capratio Call_Date_stata_format, lc(black) lw(medthick) lp(longdash_dot))
	if year<1932 & year>1919
	, title("")
	  ymt(16(1)32) yl(16(2)32, angle(horizontal) nogrid) xlabel(-14610 -14244 -13879 -13514 -13149 -12783 -12418 -12053 -11688 -11322 -10957 -10592 -10227, format(%tdCCYY))
	  ytitle("Equity Ratio in Percent") xtitle("Date")
	  legend(order(1 "New York" 2 "Chicago" 3 "Reserve Cities")
	  size(medium) cols(1) ring(0) pos(11) region(ls(none) sty(none))) 
	  xline(-10684, lc(black) lw(thin) lp(dash)) text(26 -10644 "1930 Q4", placement(3) size(medium)) 
	  xline(-11872, lc(black) lw(thin) lp(dash)) text(26 -11832 "1927 Q3", placement(3) size(medium)) 
graphregion(c(white) m(0 0 0 5)) plotregion(c(white) m(0 5 0 0)) 	  
xsize(4.8) ysize(3)
	 ;
#delimit cr	 

// END OF FILE //
