/*==============================================================================
This file replicates Figure 2 of the JMCB paper
"Countercyclical Capital Buffers: A Cautionary Tale" by

Christoffer Koch (International Monetary Fund)
Gary Richardon (UC Irvine)
Patrick Van Horn (Scripps College)

==============================================================================*/

set varabbrev off
version 15.1
clear all 

capture noisily cd ${MasterDirectory}
use "./data/xt_mod_qq.dta", replace
keep q_date dt_open size_cat eqt tier1_leverage_ratio total_risk_based_capital_ratio tier1_risk_based_capital_ratio

/*
Generating indicator for DeNovo Banks
*/
tostring dt_open, g(dt_open_str) 
gen established = qofd(date(dt_open_str,"YMD"))
format established %tqCY_!Qq
gen age = (q_date-established)/4
order dt_open establishe* q_date age, first
gen IndDeNovo = cond(age<=5,1,0)
tab q_date IndDeNovo
// keeping only non-DeNovo Banks
keep if IndDeNovo == 0 
tab q_date IndDeNovo



summ eqt tier1_leverage_ratio total_risk_based_capital_ratio tier1_risk_based_capital_ratio, d
 
// ratios in percent rather than fraction
replace tier1_leverage_ratio = 100*tier1_leverage_ratio 
replace total_risk_based_capital_ratio = 100*total_risk_based_capital_ratio 
replace tier1_risk_based_capital_ratio = 100*tier1_risk_based_capital_ratio

summ eqt tier1_leverage_ratio total_risk_based_capital_ratio tier1_risk_based_capital_ratio, d

// trimm outlieres
gen flag = 0
summ tier1_risk_based_capital_ratio, d 
replace flag = 1 if tier1_risk_based_capital_ratio > `r(p99)'
replace flag = 2 if tier1_risk_based_capital_ratio < `r(p1)' 
summ tier1_risk_based_capital_ratio if flag == 1, d 
summ tier1_risk_based_capital_ratio if flag == 2, d
replace flag = cond(flag==0,0,1)
tab q_date flag
tab flag size_cat

keep if q_date < yq(2011,1)
keep if q_date > yq(2000,4)

global d2001q4 = yq(2001,4)
global d2008q4 = yq(2008,4)

collapse (mean) mn_tier1_risk_based_cr = tier1_risk_based_capital_ratio (p50) md_tier1_risk_based_cr = tier1_risk_based_capital_ratio, by(q_date size_cat flag)
drop if flag == 1
drop flag

twoway ///
line mn_tier1_risk_based_cr q_date if size_cat == 4, lc(black) lw(medthick) lp(solid) || ///
line mn_tier1_risk_based_cr q_date if size_cat == 3, lc(black) lw(medthick) lp(longdash_dot) || ///
line mn_tier1_risk_based_cr q_date if size_cat == 2, lc(black) lw(medthick) lp(dot) || ///
line mn_tier1_risk_based_cr q_date if size_cat == 1, lc(black) lw(medthick) lp(dash) ///
xsize(4.8) ysize(3) ttitle("") ytitle("") ///
title("Tier 1 Risk-Based Capital Ratio", c(black) size(medium)) ///
xline(${d2008q4}, lc(black) lw(thin) lp(dash)) /// 
xline(${d2001q4}, lc(black) lw(thin) lp(dash)) ///  
ytick(2(1)18) ymt(2(0.5)18) yl(2(2)18, angle(horizontal) nogrid) tl(2001q1(4)2010q4, format(%tqCCYY)) ///
legend(order(1 "Banks $250bn+" ///
2 "Banks $50bn-$250bn" ///
3 "Banks $10bn-50bn" ///
4 "Banks <$10bn") size(medium) cols(1) ring(0) pos(6) region(ls(none) sty(none))) ///
graphregion(c(white) m(0 5 5 5)) plotregion(c(white) m(0 10 0 0)) /// 
subtitle("Percent", margin(b=2) width(145) size(medium) justification(left) span) ///
text(17.2 196 "2008 Q4", placement(3) size(medium)) ///
text(17.2 168 "2001 Q4", placement(3) size(medium)) 

// graph export ./output/KRVH2022JMCB_figure2.pdf, as(pdf) replace
// graph export ./output/KRVH2022JMCB_figure2.png, as(png) replace	


// END OF FILE //
