/*
filename: fig_5_results_visualization

This file categorizes and visualizes the regression output from 
1. tab_1_baseline_regressions.do
2. tab_2_robustness_regressions.do
3. tab_3_modern_regressions.do

The visualizations are meant to illustrate the robustness of the results.

Christoffer Koch
*/

set varabbrev off
version 15.0
clear all 

cd ${MasterDirectory}


// inputting the business cycles lengths manually and linking them to the output data

clear
input HistModn BusCy DurationMonths str25 Description
0 1 21 "NBER"
0 2 85 "Short-term interest rate"
0 3 104 "Consumption"
0 4 97  "DJIA"
0 5 62  "Volume of Payments" 
0 6 62  "Total Payroll" 
1 1 73  "NBER"
1 2 41  "Short-term interest rate"
1 3 61  "Consumption"
1 4 60  "DJIA"
1 5 52  "Volume of Payments" 
1 6 53  "Total Payroll" 
end
save ./output/xt_business_cycle_duration.dta, replace


use ./output/xt_visualization1.dta, clear
append using ./output/xt_visualization2.dta

drop if dtaBusCy == .

rename dta* *
gen t_stat = Estimate/StdErr

summ t_stat,d
replace t_stat = abs(t_stat)

gen significance = 0
// t-Statistics from  https://www.dummies.com/education/math/statistics/how-to-use-the-t-table-to-solve-statistics-problems/
replace significance = 1 if t_stat >= 1.281552
replace significance = 2 if t_stat >= 1.644854
replace significance = 3 if t_stat >= 1.95996
* Gary fixed line of code above which had t>=1.19
replace significance = 4 if t_stat >= 2.32635
replace significance = 5 if t_stat >= 2.57583
replace significance = 6 if t_stat >= 3.2905

label define t_stat 0 "insignificant" 1 "80" 2 "90" 3 "95" 4 "98" 5 "99" 6 "99.9"
label values significance t_stat

gen HistModn = 999
replace HistModn = 0 if strpos(Model,"age>5") > 0
replace HistModn = 1 if strpos(Model,"& IndDeNovo == 0") > 0
tab HistModn
* Here, modern was 0, historical was 1
* I changed the order, to make it consistent with labels below and business cycle definitions above.

merge m:1 HistModn BusCy using ./output/xt_business_cycle_duration.dta

label define HM 0 "Historical" 1 "Modern"
label values HistModn HM
tab HistModn

label var ID "Regression ID"
label var BusCy "Business Cycle"
label var Model "Specification Detail"
label var DepVar "Dependent Variable"
label var Estimate "Point Estimate"
label var StdErr "Standard Error"
label var t_stat "t-Statistic"
label var significance "Significance Level"
label var HistModn "Historical or Modern Business Cycle"

destring SizeCutoff, replace

sort ID
ed

format %-166s Model

generate SIFI = .
replace  SIFI = 1 if strpos(Model, "top10_size1929")> 1
replace  SIFI = 2 if strpos(Model, "top10_cent1929")> 1
replace  SIFI = 3 if strpos(Model, "top10_frgn1929")> 1
replace  SIFI = 4 if strpos(Model, "top_stb")> 1
replace  SIFI = 5 if strpos(Model, "top_nat")> 1
replace  SIFI = 6 if strpos(Model, "top_nNYC")> 1

generate Assets = .
replace  Assets = 1 if strpos(Model, "c_assets1 c_assets2 c_assets3")> 1

generate TimeFE = .
replace  TimeFE = 1 if strpos(Model, "call_id")> 1
replace  TimeFE = 1 if strpos(Model, "q_date")> 1

generate Group_Top30NYC = .
replace  Group_Top30NYC = 1 if strpos(Model, "Top30NYC == 1")> 1

generate Group_IndNYC = .
replace  Group_IndNYC = 1 if strpos(Model, "IndNYC == 1")> 1

generate Group_OutNYC = .
replace  Group_OutNYC = 1 if strpos(Model, "IndNYC ==0")> 1

generate Group_FrMem = .
replace  Group_FrMem = 1 if strpos(Model, "fr_mem == 1")> 1

generate BankFE = .
replace  BankFE = 1 if strpos(Model, " fe")> 1

generate SE_robust = .
replace  SE_robust = 1 if strpos(Model,"vce(cluster bank_id)")>1

gen BusCyDH 	= .
replace BusCyDH = 1 if HistModn==0 & BusCy==1
replace BusCyDH = 2 if HistModn==0 & BusCy==6
replace BusCyDH = 3 if HistModn==0 & BusCy==5
replace BusCyDH = 4 if HistModn==0 & BusCy==2
replace BusCyDH = 5 if HistModn==0 & BusCy==4
replace BusCyDH = 6 if HistModn==0 & BusCy==3
label define BCDH 1 "NBER" 2 "Payroll" 3 "Payments"  4 "Rate" 5 "DJIA" 6  "Cons."
label values BusCyDH BCDH

gen BusCyDM 	= .
replace BusCyDM = 1 if HistModn==1 & BusCy==2
replace BusCyDM = 2 if HistModn==1 & BusCy==5
replace BusCyDM = 3 if HistModn==1 & BusCy==6
replace BusCyDM = 4 if HistModn==1 & BusCy==4
replace BusCyDM = 5 if HistModn==1 & BusCy==3
replace BusCyDM = 6 if HistModn==1 & BusCy==1
label define BCDM 1 "Rate" 2 "Payments" 3 "Payroll"  4 "DJIA" 5 "Cons." 6  "NBER"
label values BusCyDM BCDM

gen Samples_Size_Regressions = .
replace Samples_Size_Regressions = 1 if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & ID>=1 & ID<=36 
replace Samples_Size_Regressions = 2 if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & Group_FrMem==1 
replace Samples_Size_Regressions = 3 if HistModn==0 & BusCy~=. & SIFI==4 & Assets==1 & TimeFE==1 
replace Samples_Size_Regressions = 4 if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & Group_IndNYC==1 
replace Samples_Size_Regressions = 5 if HistModn==0 & BusCy~=. & SIFI==6 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 
label define SampSize 1 "All" 2 "Fed" 3 "State" 4 "In NYC" 5 "Out NY" 
label values Samples_Size_Regressions SampSize

gen HistSizeCutoff = .
replace HistSizeCutoff=1 if SizeCutoff == "HIS Top 5  - TFE"
replace HistSizeCutoff=2 if SizeCutoff == "HIS Top 10  - TFE"
replace HistSizeCutoff=3 if SizeCutoff == "HIS Top 20  - TFE"
label define HSC 1 "Top 5" 2 "Top 10" 3 "Top 20" 
label values HistSizeCutoff HSC

generate E_type = .
replace  E_type = 1 if strpos(Model, "xtreg eqt")>0 
replace  E_type = 2 if strpos(Model, "tier1_leverage")>0 
replace  E_type = 3 if strpos(Model, "tier1_risk_based")>0 
replace  E_type = 4 if strpos(Model, "total_risk_based")>0 
label var E_type "Equity Definition"
label define EQ 1 "Equity" 2 "T1 Leverage" 3 "T1 Risk" 4 "Total Risk"
* T1 leverage is tier 1 leverage. T1 Risk is Tier 1 Risk based, etc.
label values E_type EQ

generate BigModern = .
replace  BigModern = 1 if SizeCutoff == "MOD 250000000 - TFE"
replace  BigModern = 1 if SizeCutoff == "MOD 100000000 - TFE"
replace  BigModern = 1 if SizeCutoff == "MOD 20 - TFE"
replace  BigModern = 1 if SizeCutoff == "MOD 10 - TFE"
replace  BigModern = 1 if SizeCutoff == "MOD 5 - TFE"

generate ModernTopGroup = .
replace  ModernTopGroup = 1 if SizeCutoff == "MOD 250000000 - TFE"
replace  ModernTopGroup = 2 if SizeCutoff == "MOD 100000000 - TFE"
replace  ModernTopGroup = 3 if SizeCutoff == "MOD 50000000 - TFE"
label var ModernTopGroup "Core Group"
label define MTG 1 "$250 bil." 2 "$100 bil." 3 "$50 bil."
label values ModernTopGroup MTG

generate Hold=.
replace  Hold=1 if strpos(SizeCutoff,"bhc == 1 - TFE") > 0
replace  Hold=0 if strpos(SizeCutoff,"bhc == 0 - TFE") > 0
label define Hold 0 "No" 1 "Yes"
label values Hold Hold


* Baseline - regressions plotted by business cycle with length ranked 1 to 6
#delimit ;
twoway 
	(scatter Estimate BusCyDH if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>3 & ID>=1 & ID<=36 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msymbol(O) msize(large) legend(off) ) 
	(scatter Estimate BusCyDH if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=3 & ID>=1 & ID<=36 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msymbol(Oh) msize(large) legend(off) ) 
	(scatter Estimate BusCyDH if HistModn==0 & BusCy~=. & SIFI==2 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>3 & ID>=1 & ID<=36 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs10) msize(medium) msymbol(D) legend(off) ) 
	(scatter Estimate BusCyDH if HistModn==0 & BusCy~=. & SIFI==2 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=3 & ID>=1 & ID<=36 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs10) msize(medium)  msymbol(Dh) legend(off) ) 
	,
	ylabel(,angle(horizontal) labsize(large)) xtitle(" " "Business Cycle", size(large)) xlabel(1 2 3 4 5 6, valuelabel labsize(large)) graphregion(c(white)) plotregion(c(white) margin(15 15 0 0) ) ysize(3) xsize(4.8)
	;
#delimit cr

graph export ".\output\fig4_A_historical_baseline.pdf", as(pdf) replace
graph export ".\output\fig4_A_historical_baseline.png", as(png) replace

* Baseline - regressions plotted by business cycle with length ranked 1 to 6 -- Equity versus Risk weighted equity
#delimit ;
twoway 
	(scatter Estimate BusCyDH if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>3 & ID>=1 & ID<=36 , yscale(range(0 7)) ylabel(0(1)7) mcolor(gs0) msymbol(O) msize(large) legend(off) ) 
	(scatter Estimate BusCyDH if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=3 & ID>=1 & ID<=36 , yscale(range(0 7)) ylabel(0(1)7) mcolor(gs0) msymbol(Oh) msize(large) legend(off) ) 
	(scatter Estimate BusCyDH if SizeCutoff=="HIS top10_size1929 rw_eqt  - TFE" & significance>3 , yscale(range(0 7)) ylabel(0(1)7) mcolor(gs10) msize(medium) msymbol(D) legend(off) ) 
	(scatter Estimate BusCyDH if SizeCutoff=="HIS top10_size1929 rw_eqt  - TFE" & significance<=3 , yscale(range(0 7)) ylabel(0(1)7) mcolor(gs10) msize(medium)  msymbol(Dh) legend(off) ) 
	,
	ylabel(,angle(horizontal) labsize(large)) xtitle(" " "Business Cycle", size(large)) xlabel(1 2 3 4 5 6, valuelabel labsize(large)) graphregion(c(white)) plotregion(c(white) margin(15 15 0 0) ) ysize(3) xsize(4.8)
	;
#delimit cr

graph export ".\output\fig4_B_historical_baseline.pdf", as(pdf) replace
graph export ".\output\fig4_B_historical_baseline.png", as(png) replace


* NOTE: SUBSET WITH ONLY STATE BANKS LACKS BANK FIXED EFFECTS AND ROBUST STANDARD ERRORS
* NOTE: Lowest estimates from upstate NY, do not include NY City. Pattern still holds, but muted, because largest and most connected banks not in sample.


* HISTORICAL BY SIZE CUTOFF 
#delimit ;
twoway 
	(scatter Estimate HistSizeCutoff if HistSizeCutoff~=. & significance>1, yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(large) msymbol(o) legend(off)  ) 
	(scatter Estimate HistSizeCutoff if HistSizeCutoff~=. & significance<=1, yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(vlarge)msymbol(pipe) msangle(90) legend(off) ) 
	, xlabel(1 2 3, valuelabel labsize(large)) xtitle(" " "Banks in Core", size(large)) ylabel(,angle(horizontal) labsize(large)) graphregion(c(white)) plotregion(c(white) margin(15 15 0 0) ) ysize(3) xsize(4.8)
	;
#delimit cr

graph export ".\output\fig4_C_historic_robustness.pdf", as(pdf) replace
graph export ".\output\fig4_C_historic_robustness.png", as(png) replace



* ALL SIZE REGRESSIONS - Plotted By Gropus exposed to common shocks and unobservables
#delimit ;
twoway 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>2 & ID>=1 & ID<=36 ,  yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(large) msymbol(o) legend(off)  ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=2 & ID>=1 & ID<=36 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(vlarge)msymbol(pipe) msangle(90) legend(off) ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>2 & Group_IndNYC==1 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(large) msymbol(o) legend(off)  ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=2 & Group_IndNYC==1 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(vlarge)msymbol(pipe) msangle(90) legend(off) ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>2 & Group_FrMem==1 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(large) msymbol(o) legend(off)  ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==1 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=2 & Group_FrMem==1 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(vlarge)msymbol(pipe) msangle(90) legend(off) ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==4 & Assets==1 & TimeFE==1 & significance>2 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(large) msymbol(o) legend(off) ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==4 & Assets==1 & TimeFE==1 & significance<=2 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(vlarge)msymbol(pipe) msangle(90) legend(off) ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==6 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance>2 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(large) msymbol(o) legend(off)  ) 
	(scatter Estimate Samples_Size_Regressions if HistModn==0 & BusCy~=. & SIFI==6 & Assets==1 & BankFE==1 & TimeFE==1 & SE_robust==1 & significance<=2 , yscale(range(0 5)) ylabel(0(1)5) mcolor(gs0) msize(vlarge)msymbol(pipe) msangle(90) legend(off) ) 
	, xlabel(1 2 3 4 5, valuelabel labsize(large)) xtitle(" " "Sample", size(large)) ylabel(,angle(horizontal) labsize(large)) graphregion(c(white)) plotregion(c(white) margin(15 15 0 0) ) ysize(3) xsize(4.8)
	;
#delimit cr

graph export ".\output\fig4_D_historic_robustness.pdf", as(pdf) replace
graph export ".\output\fig4_D_historic_robustness.png", as(png) replace


/*

GRAPH EDIT 

scatter mpg weight, xlabel(,labsize(medlarge))
gr_edit xaxis1.edit_tick 1 2000 `"{fontface "Tahoma": 2,000}"' 2 3000
`"{fontface "Tahoma": 3,000}"' 3 4000 `"{fontface "Tahoma": 4,000}"' 4
5000 `"{fontface "Tahoma": 5,000}"', tickset(major)
