capture noisily log using ./output/log_2_robustness_regressions.log, text name(robustness) replace
/*
filename: tab_2_robustness_regressions.do

This file runs some robustness specificiatons.

Programs in this file:

- RegressionsRobustnessCheck1 
- RegressionsRobustnessCheck2


Programs from outside this file:
- NewHistoricalReportingTemplate (from tab_1_baseline_regression.do)
- results2xls (from tab_1_baseline_regression.do)
- results2dta (from tab_1_baseline_regression.do)

/*
syntax 
RegressionsRobustnessCheck1 `1' `2' `3' `4'
`1' ... Name of Excel sheet tab (e.g. "Rob 1 - NCY")
`2' ... Restriction (e.g. "& IndNYC == 1")
`3' ... Auxiliary controls ( c_assets1 ...)
`4' ... dependent variable (eqt or rw_eqt)
*/
*/


capture noisily program drop RegressionsRobustnessCheck1
program RegressionsRobustnessCheck1

	global SubSet "age>5 & eqt <50 `2'"
	global controls "c_assets1 c_assets2 c_assets3 `3'"
	
		forvalues bc = 1/6 {
	
		/**************************/
		// TOP 10 SIZED BANKS 	  //
		/**************************/
		
		display "Business Cycle: `bc'"
		// no time-fixed effects
		xtreg `4' i.top10_size1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 2
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'" "HIS top10_size1929 `4' `2'"		
		
		display "Business Cycle: `bc'"
		// time-fixed effects	
		xtreg `4' i.top10_size1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
		lincom 1.top10_size1929#c.h_bc_`bc', cformat(%9.2fc)  
		results2xls `bc' 5	
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'" "HIS top10_size1929 `4' `2' - TFE"
		
		/**************************/
		// TOP 10 "CENTRAL" BANKS //
		/**************************/

		display "Business Cycle: `bc'"		
		// no time-fixed effects
		xtreg `4' i.top10_cent1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 8	
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'" "HIS top10_cent1929 `4' `2'"		
		
		display "Business Cycle: `bc'"		
		// time-fixed effects
		xtreg `4' i.top10_cent1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
		lincom 1.top10_cent1929#c.h_bc_`bc', cformat(%9.2fc)  
		results2xls `bc' 11
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'"	"HIS top10_cent1929 `4' `2' - TFE"	
	
		/**************************/
		// TOP 10 FOREIGN BANKS   //
		/**************************/
		
		display "Business Cycle: `bc'"
		// no time-fixed effects
		xtreg `4' i.top10_frgn1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 14	
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'"	"HIS top10_frgn1929 `4' `2'"	
		
		display "Business Cycle: `bc'"		
		// time-fixed effects
		xtreg `4' i.top10_frgn1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
		lincom 1.top10_frgn1929#c.h_bc_`bc', cformat(%9.2fc)  
		results2xls `bc' 17
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'"	"HIS top10_frgn1929 `4' `2' - TFE"	
		
	}

	display "`1'"
	
	export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ///
	ResultsColumn4 ResultsColumn5 ResultsColumn6 in 1/20 using "./output/tab_baseline.xlsx", ///
	sheet("`1' `4'") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt
	
end 

capture noisily program drop RegressionsRobustnessCheck2
program define RegressionsRobustnessCheck2

	global SubSet "age>5 & eqt <50 `2'"
	global controls "c_assets1 c_assets2 c_assets3 `3'"
	
		forvalues bc = 1/6 {
	
		/**************************/
		// different subgroups    //
		/**************************/
		
		display "Business Cycle: `bc'"
		// no time-fixed effects
		xtreg `5' i.`4'##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.`4'#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 2
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'"	"HIS `4' `5' `2'"	
		
		display "Business Cycle: `bc'"
		// time-fixed effects
		xtreg `5' i.`4'##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display `"`e(cmdline)'"'
		lincom 1.`4'#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
		lincom 1.`4'#c.h_bc_`bc', cformat(%9.2fc)  
		results2xls `bc' 5
		di `"`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"'
		results2dta "`bc'" `"`e(cmdline)'"' "`e(depvar)'" "`r(estimate)'" "`r(se)'"	"HIS `4' `5' `2' - TFE"	
		
	}

	display "`1'"
	
	export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ///
	ResultsColumn4 ResultsColumn5 ResultsColumn6 in 1/20 using "./output/tab_baseline.xlsx", ///
	sheet("`1' `5'") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt
	
end 


/* SOME VARIABLE TRANSFORMATIONS FOR THE ROBUSTNESS CHECKS */

// SIZE RANKING WITHIN CITY OF NEW YORK
// generates variable: Top30NYC
gsort call_id IndNYC -assets
by call_id IndNYC: gen NYCRank = cond(IndNYC == 1,_n,999)
gen Top30NYC = 1 if NYCRank <=30

// TOP SIZE DECILE AMONG THE STATE BANK AND TRUSTS
// generates variable: d_stb_assets
// ssc install egenmore
egen d_stb_assets = xtile(assets) if (source == "stb_qq" | source == "stt_qq"), nq(10) by(call_id)
tab call_id d_stb_assets, m // check command xtile worked appropriately

gen top_stb = cond(d_stb_assets == 10,1,0)
tab top_stb if (source == "stb_qq" | source == "stt_qq")
tab call_id top_stb if (source == "stb_qq" | source == "stt_qq")

// TOP SIZE DECILE AMONG THE NATIONAL BANKS (CAUTION RE QQ AS THERE ARE ONLY 4-5)
// generates variable: d_nat_assets 
egen d_nat_assets = xtile(assets) if (source == "nat_qq" | source == "nat_qa"), nq(10) by(call_id)
tab call_id d_nat_assets, m // check command xtile worked appropriately

gen top_nat = cond(d_nat_assets == 10,1,0)
tab top_nat if (source == "nat_qq" | source == "nat_qa")
tab call_id top_nat if (source == "nat_qq" | source == "nat_qa")

// TOP SIZE DECILE AMONG THOSE BANKS OUTSIDE OF NEW YORK CITY
// generates variable: d_nNYC_assets
egen d_nNYC_assets = xtile(assets) if IndNYC == 0, nq(10) by(call_id)
tab call_id d_nNYC_assets, m // check command xtile worked appropriately

gen top_nNYC = cond(d_nNYC_assets == 10,1,0)
tab top_nNYC if IndNYC == 0
tab call_id top_nNYC if IndNYC == 0


// CONTROLLING FOR DEPOSITS
gen dep_ass_ratio = 100*(l_tot_dep/assets)
gen check = cond((dep_ass_ratio == . | dep_ass_ratio == 0),0,1)
tab d_date check, m
tab call_id check, m
drop check
summarize dep_ass_ratio, d

/* EXECUTING THE ROBUSTNESS CHECKS */

sort bank_id call_id d_date 
xtset bank_id call_id
NewHistoricalReportingTemplate

RegressionsRobustnessCheck1 "HIS Rob 1 - NYC" "& IndNYC == 1" ""  "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck1 "HIS Rob 2 - NYCtop30" "& Top30NYC == 1" ""  "eqt"
//NewHistoricalReportingTemplate
//RegressionsRobustnessCheck1 "Rob 3 - nNYC" "& IndNYC == 0" ""  "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck2 "HIS Rob 3 - nNYC" "& IndNYC == 0" "" "top_nNYC"  "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck1 "HIS Rob 4.1 - NAT" `"& (source == "nat_qq" | source == "nat_qa")"' ""  "eqt"
//NewHistoricalReportingTemplate
//RegressionsRobustnessCheck1 "Rob 5 - STE" `"& (source == "stt_qq" | source == "stb_qa")"' ""  "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck2 "HIS Rob 4.2 - NAT" `"& (source == "nat_qq" | source == "nat_qa")"' "" "top_nat"  "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck2 "HIS Rob 5 - STE" `"& (source == "stt_qq" | source == "stb_qa")"' "" "top_stb"  "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck1 "HIS Rob 6 - FRB" "& fr_mem == 1" "" "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck1 "HIS Rob 7 - PASS" "" "" "eqt"
NewHistoricalReportingTemplate
RegressionsRobustnessCheck1 "HIS Rob 8 - DEPS" "" "dep_ass_ratio" "eqt"

// GENERATING RISK_WEIGHTED ASSETS
gen rw_assets = 0.75*a_tot_loans +0.0*a_tot_cash + 0.50*a_tot_inv + a_tot_other
gen rw_eqt = 100*equity/rw_assets

RegressionsRobustnessCheck1 "HIS Rob 9 - rw_eqt" "" "" "rw_eqt"


gsort call_id -assets
by call_id: gen quarter_rank = _n
by call_id: gen top_size = cond(_n<=20,1,0)

capture noisily program drop HistoricRankBasedRegressions
program define HistoricRankBasedRegressions

      /*
      This file sorts the modern banks by assets in each quarter and compares the 
      k-highest size-ranked banks to the remaining banks.
      */

      gsort call_id -assets
      //by q_date: gen quarter_rank = _n
      by call_id: replace top_size = cond(_n<=`1',1,0)
      
	  di "Checking on the number of banks in the top size"
	  tab call_id top_size
	  
      // clearing the reporting template and replacing it with a blank one
      // to prevent "carry over" from stale (previous) estimates
      NewHistoricalReportingTemplate2 `1'
      
      forvalues bc = 1/6 {

            global SubSet "age>5 & eqt <50 `2'"
		    global controls "c_assets1 c_assets2 c_assets3 `3'"

            display "Business Cycle: `bc'"      
            display "Number of largest banks: `1'"
            // no time-fixed effects
            xtreg eqt i.top_size##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
            display "`e(cmdline)'"
            lincom 1.top_size#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
            results2xls `bc' 1
            di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
            results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "HIS Top `1'"
            
            display "Business Cycle: `bc'"      
            display "Number of largest banks: `1'"
            // time-fixed effects
            xtreg eqt i.top_size##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
            display "`e(cmdline)'"
            lincom 1.top_size#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
            lincom 1.top_size#c.h_bc_`bc', cformat(%9.2fc) 
            results2xls `bc' 5
            di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
            results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "HIS Top `1'  - TFE"

            
      }

      export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
      in 1/25 using "./output/tab_baseline.xlsx", sheet("his top `1'") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt
      
end

capture noisily program drop NewHistoricalReportingTemplate2
program define NewHistoricalReportingTemplate2

	/*
	As there might be re-sorts during the intermittent data management
	each set of regressions is preceded by a new template that is
	then exported to Excel. This program creates the historical regressions
	table template.
	*/

	capture noisily drop Results*
	gen ResultsColumnT = "" in 1
	replace ResultsColumnT = "Top `1'" in 2
	replace ResultsColumnT = "Size" in 3

	gen ResultsColumn0 = "Specification" in 1
	replace ResultsColumn0 = "Baseline" in 2
	replace ResultsColumn0 = "S.E." in 3
	replace ResultsColumn0 = "Time-Fixed Effects" in 5
	replace ResultsColumn0 = "S.E." in 6

	gen ResultsColumn1 = "Business Cycle Definition 1" in 1
	gen ResultsColumn2 = "Business Cycle Definition 2" in 1
	gen ResultsColumn3 = "Business Cycle Definition 3" in 1
	gen ResultsColumn4 = "Business Cycle Definition 4" in 1
	gen ResultsColumn5 = "Business Cycle Definition 5" in 1
	gen ResultsColumn6 = "Business Cycle Definition 6" in 1

	label var ResultsColumn1 "NBER"
	label var ResultsColumn2 "Short-term interest rate"
	label var ResultsColumn3 "Consumption"
	label var ResultsColumn4 "DJIA"
	label var ResultsColumn5 "Volume of Payments"
	label var ResultsColumn6 "Total Payroll"

	order ResultsColumnT Results*, first
	
end
// TOP 10 SIZED BANKS EACH QUARTER

HistoricRankBasedRegressions 5
HistoricRankBasedRegressions 10
HistoricRankBasedRegressions 20
HistoricRankBasedRegressions 30
HistoricRankBasedRegressions 40
HistoricRankBasedRegressions 50
HistoricRankBasedRegressions 100




// ssc install savesome
savesome dtaID dtaBusCy dtaModel dtaDepVar dtaSizeCutoff dtaEstimate dtaStdErr using ./output/xt_visualization1.dta, replace

capture noisily log close robustness

// END OF FILE //
