/*
filename: tab_4_joint_modern_historical_regressions.do

This does top banks and decile-decile comparisons between
the historical and modern samples in a "pooled" data set.

*/

clear
// running file that combines all four historical data sets
do dtm_combine_historical_banks.do

tab d_date
tab source if d_date==.

merge m:1 d_date using ts_business_cycles_on_unit_interval.dta

tab _merge

keep if _merge ==3
drop _merge
drop m_bc_*
drop if bank_id == .

replace year = year(d_date)
drop age*
gen age = year - organized
order cent_rank_in_call_id size_rank_in_call_id source call_id age 

/*
We generate a flag to remove those national bank observations that are in both nat_qa and nat_qq.
*/

gen flag=0
replace flag = 1 if source == "nat_qa" & dbl_id>9000 &  (call_id == 3 | call_id == 7 | call_id == 11 | call_id == 15 | call_id == 19 | call_id == 23 | call_id == 26 | call_id == 31 | call_id == 35)

drop if flag==1

duplicates list bank_id call_id
duplicates list bank_id name call_id



drop if name == "BLANK"
drop if name == "NATIONAL BANK OF BAY RIDGE, BROOKLYN"
drop if name == "GLENS FALLS, FIRST"

xtset bank_id call_id

// ssc install egenmore, replace
egen decile_assets = xtile(assets), nq(10) by(call_id)

// GENERATING RISK_WEIGHTED ASSETS
gen rw_assets = 0.75*a_tot_loans +0.0*a_tot_cash + 0.50*a_tot_inv + a_tot_other
gen RW_EQTY = 100*equity/rw_assets
rename eqt EQTY

merge m:1 d_date using ./data/ts_business_cycles_on_unit_interval.dta
tab _merge
keep if _merge ==3
drop _merge
drop m_bc_*
rename h_bc_* bc_*
drop if bank_id == .

gen IndDeNovo = cond(age<=5,1,0)
tab IndDeNovo, m

frame copy default HIST

clear
use ./data/xt_mod_qq.dta, clear

/*
Generating indicator for DeNovo Banks
*/
tostring dt_open, g(dt_open_str) 
gen established = qofd(date(dt_open_str,"YMD"))
format established %tqCY_!Qq
gen age = (q_date-established)/4
order dt_open establishe* q_date age, first
gen IndDeNovo = cond(age<=5,1,0)
tab q_date IndDeNovo, m


merge m:1 d_date using ./data/ts_business_cycles_on_unit_interval.dta
tab _merge
keep if _merge ==3
drop _merge
drop h_bc_*
drop if bank_id == .



summ eqt tier1_leverage_ratio total_risk_based_capital_ratio tier1_risk_based_capital_ratio, d
 
// ratios in percent rather than fraction
replace tier1_leverage_ratio = 100*tier1_leverage_ratio 
replace total_risk_based_capital_ratio = 100*total_risk_based_capital_ratio 
replace tier1_risk_based_capital_ratio = 100*tier1_risk_based_capital_ratio

rename m_bc* bc*

gen c_assets1 = 100*(loans/assets)
gen c_assets2 = 100*(securities/assets)
gen c_assets3 = 100*(cash/assets)

rename eqt EQTY
rename tier1_leverage_ratio T1LR
rename total_risk_based_capital_ratio TRBR
rename tier1_risk_based_capital_ratio T1RB

/*
The objective is to run a regression which is "pooled" across
historical and modern data sets.
*/

frames dir
frame copy default EQTY, replace
frame copy default T1LR, replace
frame copy default T1RB, replace
frame copy default TRBR, replace

frames dir



frame change HIST

// ASSET PORTFOLIO DECOMPOSITION
gen c_assets1 = 100*(a_tot_loans/assets)
gen c_assets2 = 100*(a_tot_inv/assets)
gen c_assets3 = 100*(a_tot_cash/assets)
gen c_assets4 = 100*(a_tot_other/assets)

summ c_assets1, d
summ c_assets2, d
summ c_assets3, d
summ c_assets4, d

keep d_date EQTY RW_EQTY bank_id call_id source name age top10_size1929 top10_frgn1929 top10_cent1929 bc_1 bc_2 bc_3 bc_4 bc_5 bc_6 flag c_assets* decile_assets assets IndDeNovo

save ./data/xt_HIST_aux.dta, replace

capture noisily log close his_mod_deciles
capture noisily log using ./output/log_his_mod_decile_comparison.log, text replace name(his_mod_deciles)

capture noisily program drop DecileRegressionsHisMod
program define DecileRegressionsHisMod

	capture noisily frame drop `1'_aux	
	frame copy `1' `1'_aux
	frame change `1'

	// winsorizing
	gen flag = 0
	summ `1', d 
	replace flag = 1 if `1' > `r(p99)'
	replace flag = 2 if `1' < `r(p1)' 
	summ `1' if flag == 1, d
	summ `1' if flag == 2, d
	replace flag = cond(flag==0,0,1)
	tab q_date flag
	drop if flag == 1

	// ssc install egenmore, replace
	egen decile_assets = xtile(assets), nq(10) by(q_date)

	//rename eqt EQTY
	append using ./data/xt_HIST_aux.dta

	xtset d_date bank_id
	order bank_id, first

	order bank_id name call_id d_date EQTY RW_EQTY T1LR T1RB TRBR decile_assets top* assets call_id bc_* c_asset* 

	format d_date %tdCY!-N!-D
	format assets %21.0fc

	replace year = year(d_date)
	gen IndHisMod = cond(year<1950,0,1)
	tab IndHisMod
	tab IndDeNovo IndHisMod, m

	// replacing the dependent variable depending on what modern capital measure
	// is being tested
	replace EQTY = `1' if IndHisMod == 1 
	
	replace call_id = q_date if IndHisMod == 1
	xtset bank_id call_id

	forvalues bc = 1/6 {

		di "Business Cycle: `bc'"
		di "Modern Capital Measure: `1'"
		xtreg EQTY i.IndHisMod#i.decile_assets#c.bc_`bc' c_assets1 c_assets2 c_assets3 if IndDeNovo == 0 & EQTY <50 & EQTY > 4 & bc_`bc'!=., fe vce(cluster bank_id)
		di "`e(cmd)'"
		tab year if e(sample)	
		forvalues decile = 1/10 {
			di "Size Decile: `decile' comparison HIST - MODN"
			di "Business Cycle: `bc'"
			di "Modern Measure: `1'"
			lincom 0.IndHisMod#`decile'.decile_assets#bc_`bc' - 1.IndHisMod#`decile'.decile_assets#bc_`bc'
		}
	}

	// restoring the original frame, so double winsorizing does not occur
	frame change HIST
	frame copy `1'_aux `1', replace
	capture noisily frame drop `1'_aux
	frame change `1'
	frames dir	
	
end

DecileRegressionsHisMod EQTY
DecileRegressionsHisMod T1LR
DecileRegressionsHisMod T1RB
DecileRegressionsHisMod TRBR


capture noisily log close his_mod_deciles
// logging the top diff-in-diff seperately
capture noisily log using ./output/log_his_mod_topDiD_comparison.log, text replace name(his_mod_DiD)

capture noisily program drop _all
program define DiDReportingTemplate

	/*
	As there might be re-sorts during the intermittent data management
	each set of regressions is preceded by a new template that is
	then exported to Excel. This program creates the historical regressions
	table template.
	*/

	capture noisily drop Results*

	gen ResultsColumn0 = "Specification" in 1
	replace ResultsColumn0 = "EQTY" in 2
	replace ResultsColumn0 = "S.E." in 3
	replace ResultsColumn0 = "" in 4	
	replace ResultsColumn0 = "T1LR" in 5
	replace ResultsColumn0 = "S.E." in 6
	replace ResultsColumn0 = "" in 7
	replace ResultsColumn0 = "T1RB" in 8
	replace ResultsColumn0 = "S.E." in 9
	replace ResultsColumn0 = "" in 10
	replace ResultsColumn0 = "TRBR" in 11	
	replace ResultsColumn0 = "S.E." in 12	
	
	gen ResultsColumn1 = "Business Cycle Definition 1" in 1
	gen ResultsColumn2 = "Business Cycle Definition 2" in 1
	gen ResultsColumn3 = "Business Cycle Definition 3" in 1
	gen ResultsColumn4 = "Business Cycle Definition 4" in 1
	gen ResultsColumn5 = "Business Cycle Definition 5" in 1
	gen ResultsColumn6 = "Business Cycle Definition 6" in 1

	label var ResultsColumn1 "NBER"
	label var ResultsColumn2 "Short-term interest rate"
	label var ResultsColumn3 "Consumption"
	label var ResultsColumn4 "DJIA"
	label var ResultsColumn5 "Volume of Payments"
	label var ResultsColumn6 "Total Payroll"

	order Results*, first
	
end

DiDReportingTemplate

capture noisily program drop TopDiffInDiffRegressionsHisMod
program define TopDiffInDiffRegressionsHisMod

	capture noisily frame drop `1'_aux
	frame copy `1' `1'_aux
	frame change `1'

	// winsorizing
	gen flag = 0
	summ `1', d 
	replace flag = 1 if `1' > `r(p99)'
	replace flag = 2 if `1' < `r(p1)' 
	summ `1' if flag == 1, d
	summ `1' if flag == 2, d
	replace flag = cond(flag==0,0,1)
	tab q_date flag
	drop if flag == 1

	//rename eqt EQTY
	append using ./data/xt_HIST_aux.dta

	replace year = year(d_date)
	gen IndHisMod = cond(year<1950,0,1)
	tab IndHisMod
	tab IndDeNovo IndHisMod, m	
	
	gen IndTop = 0
	order IndTop top*, first
	replace IndTop = `2' if `2' !=.
	replace IndTop = cond((assets>250000000 & IndHisMod == 1),1,IndTop)

	order bank_id name call_id d_date EQTY RW_EQTY T1LR T1RB TRBR decile_assets top* assets call_id bc_* c_asset* 

	format d_date %tdCY!-N!-D
	format assets %21.0fc

	// replacing the dependent variable depending on what modern capital measure
	// is being tested
	replace EQTY = `1' if IndHisMod == 1 
	
	replace call_id = q_date if IndHisMod == 1
	xtset bank_id call_id

	forvalues bc = 1/6 {

		di "Business Cycle: `bc'"
		di "Modern Capital Measure: `1'"
		xtreg EQTY i.IndHisMod#i.IndTop#c.bc_`bc' c_assets1 c_assets2 c_assets3 if IndDeNovo == 0 & EQTY <50 & EQTY > 4 & bc_`bc'!=., fe vce(cluster bank_id)
		di "`e(cmd)'"
		tab year if e(sample)	
			di "Size Decile: `decile' comparison HIST - MODN"
			di "Business Cycle: `bc'"
			di "Modern Measure: `1'"
			di "Historical Comparison Group: `2'"
			di "Diff 1"
			lincom 0.IndHisMod#1.IndTop#bc_`bc' - 1.IndHisMod#1.IndTop#bc_`bc'
			di "Diff 2"
			lincom 0.IndHisMod#0.IndTop#bc_`bc' - 1.IndHisMod#0.IndTop#bc_`bc'
			di "Diff-in-Diff"
			lincom (0.IndHisMod#1.IndTop#bc_`bc' - 1.IndHisMod#1.IndTop#bc_`bc') ///
        			- (0.IndHisMod#0.IndTop#bc_`bc' - 1.IndHisMod#0.IndTop#bc_`bc')
					
		}
	
	// restoring the original frame, so double winsorizing does not occur
	frame change HIST
	frame copy `1'_aux `1', replace
	capture noisily frame drop `1'_aux
	frame change `1'
	frames dir
		
end

TopDiffInDiffRegressionsHisMod EQTY top10_size1929
TopDiffInDiffRegressionsHisMod T1LR top10_size1929
TopDiffInDiffRegressionsHisMod T1RB top10_size1929
TopDiffInDiffRegressionsHisMod TRBR top10_size1929

TopDiffInDiffRegressionsHisMod EQTY top10_cent1929
TopDiffInDiffRegressionsHisMod T1LR top10_cent1929
TopDiffInDiffRegressionsHisMod T1RB top10_cent1929
TopDiffInDiffRegressionsHisMod TRBR top10_cent1929

TopDiffInDiffRegressionsHisMod EQTY top10_frgn1929
TopDiffInDiffRegressionsHisMod T1LR top10_frgn1929
TopDiffInDiffRegressionsHisMod T1RB top10_frgn1929
TopDiffInDiffRegressionsHisMod TRBR top10_frgn1929

capture noisily program drop XLSXTopDiDRegressionsHisMod
program define XLSXTopDiDRegressionsHisMod

	capture noisily frame drop `1'_aux
	frame copy `1' `1'_aux
	frame change `1'

	// winsorizing
	capture noisily drop flag
	gen flag = 0
	summ `1', d 
	replace flag = 1 if `1' > `r(p99)'
	replace flag = 2 if `1' < `r(p1)' 
	summ `1' if flag == 1, d
	summ `1' if flag == 2, d
	replace flag = cond(flag==0,0,1)
	tab q_date flag
	// drop if flag == 1

	//rename eqt EQTY
	append using ./data/xt_HIST_aux.dta

	replace year = year(d_date)
	gen IndHisMod = cond(year<1950,0,1)
	tab IndHisMod
	tab IndDeNovo IndHisMod, m	
	
	gen IndTop = 0
	order IndTop top*, first
	replace IndTop = `2' if `2' !=.
	replace IndTop = cond((assets>250000000 & IndHisMod == 1),1,IndTop)

	order bank_id name call_id d_date EQTY RW_EQTY T1LR T1RB TRBR decile_assets top* assets call_id bc_* c_asset* 
	
	format d_date %tdCY!-N!-D
	format assets %21.0fc

	// replacing the dependent variable depending on what modern capital measure
	// is being tested
	replace EQTY = `1' if IndHisMod == 1 
	
	replace call_id = q_date if IndHisMod == 1
	
	xtset bank_id call_id

	if "`1'" == "EQTY" {
		local row = 2
	}
	if "`1'" == "T1LR" {
		local row = 5
	}
	if "`1'" == "T1RB" {
		local row = 8
	}
	if "`1'" == "TRBR" {
		local row = 11
	}	
	
	DiDReportingTemplate		
		
	forvalues bc = 1/6 {

		di "Business Cycle: `bc'"
		di "Modern Capital Measure: `1'"
		xtreg EQTY i.IndHisMod#i.IndTop#c.bc_`bc' c_assets1 c_assets2 c_assets3 if IndDeNovo == 0 & flag == 0 & EQTY <50 & EQTY > 4 & bc_`bc'!=., fe vce(cluster bank_id)
		di "`e(cmd)'"
		tab year if e(sample)	
			di "Size Decile: `decile' comparison HIST - MODN"
			di "Business Cycle: `bc'"
			di "Modern Measure: `1'"
			di "Historical Comparison Group: `2'"
			di "Diff 1"
			lincom 0.IndHisMod#1.IndTop#bc_`bc' - 1.IndHisMod#1.IndTop#bc_`bc'
			di "Diff 2"
			lincom 0.IndHisMod#0.IndTop#bc_`bc' - 1.IndHisMod#0.IndTop#bc_`bc'
			di "Diff-in-Diff"
			lincom (0.IndHisMod#1.IndTop#bc_`bc' - 1.IndHisMod#1.IndTop#bc_`bc') ///
        			- (0.IndHisMod#0.IndTop#bc_`bc' - 1.IndHisMod#0.IndTop#bc_`bc')
			results2xls `bc' `row'
					
		}
	
	frame put ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6, into(RES_`1') 
	
	// restoring the original frame, so double winsorizing does not occur
	frame change HIST
	frame copy `1'_aux `1', replace
	capture noisily frame drop `1'_aux
	frame change `1'
	frames dir
		
end

capture noisily program drop results2xls
program define results2xls
	/*
	This program puts the results with appropriate significance "stars" 
	into a simple exportable format.

	syntax -- results2xls c1 r1 -- where c1 is the column and r1 the row numnber
	standar errors are automatically added one row underneath in parenthesis.
	*/

	local counter1 = `2'
	local counter2 = `counter1' + 1

	local aux1: di %9.2fc `r(estimate)' 
	if `r(p)' <=0.01 {
		replace ResultsColumn`1' = "`aux1'***" in `counter1'
	}
	else if `r(p)' <=0.05 {
		replace ResultsColumn`1' = "`aux1'**" in `counter1'
	}
	else if `r(p)' <=0.1 {
		replace ResultsColumn`1' = "`aux1'*" in `counter1'
	}
	else if `r(p)' > 0.1 {
		replace ResultsColumn`1' = "`aux1'" in `counter1'
	}
	local aux2: di %9.2fc `r(se)'
	replace ResultsColumn`1' = "(`aux2')" in `counter2'
	replace ResultsColumn`1' = subinstr(ResultsColumn`1'," ","",.) in 2/l
	
end 

XLSXTopDiDRegressionsHisMod EQTY top10_size1929
XLSXTopDiDRegressionsHisMod T1LR top10_size1929
XLSXTopDiDRegressionsHisMod T1RB top10_size1929
XLSXTopDiDRegressionsHisMod TRBR top10_size1929

frame change RES_EQTY
export excel ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 2/3 using "./output/tab_DiD.xlsx", sheet("DiD Summary") cell(b1) firstrow(varlabels) keepcellfmt replace

//frame put in 2/3, into(test_frame)
frame change RES_T1LR
export excel ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 5/6 using "./output/tab_DiD.xlsx", sheet("DiD Summary", modify) cell(b5) keepcellfmt
//frame put in 5/6, into(test_frame)

frame change RES_T1RB
//frame put Results* in 8/9, into(test_frame)
export excel ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 8/9 using "./output/tab_DiD.xlsx", sheet("DiD Summary", modify) cell(b8) keepcellfmt

frame change RES_TRBR
//frame put Results* in 11/12, into(test_frame)
export excel ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 11/12 using "./output/tab_DiD.xlsx", sheet("DiD Summary", modify) cell(b11) keepcellfmt



capture noisily log close his_mod_DiD

erase ./data/xt_HIST_aux.dta

// END OF FILE //
