/*
filename: tab_7_added_robustness.do
This file runs some further robustness specificiatons.
*/ 

use ./data/xt_mod_qq.dta, clear

merge m:1 d_date using ./data/ts_business_cycles_on_unit_interval.dta
tab _merge
keep if _merge ==3
drop _merge
drop h_bc_*
drop if bank_id == .

// generating six results summaries for the subsequent results visualization  
gen dtaID = .
gen dtaBusCy = .
gen dtaModel = ""
gen dtaDepVar = ""
gen dtaSizeCutoff = ""
gen dtaEstimate = . 
gen dtaStdErr = .



use ./data/xt_mod_qq.dta, clear

merge m:1 d_date using ./data/ts_business_cycles_on_unit_interval.dta
tab _merge
keep if _merge ==3
drop _merge
drop h_bc_*
drop if bank_id == .

// generating six results summaries for the subsequent results visualization  
gen dtaID = .
gen dtaBusCy = .
gen dtaModel = ""
gen dtaDepVar = ""
gen dtaSizeCutoff = ""
gen dtaEstimate = . 
gen dtaStdErr = .



capture noisily program drop ModernRankBasedRegressions2
program define ModernRankBasedRegressions2

	/*
	This file sorts the modern banks by assets in each quarter and compares the 
	k-highest size-ranked banks to the remaining banks.

	
	`1' ... number of k-highest ranked banks
	`2' ... flag for asset cutoff
	`3' ... label for the asset size cutoff
	*/

	gsort q_date -assets
	//by q_date: gen quarter_rank = _n
	by q_date: replace top_size = cond(_n<=`1',1,0)
	
	// clearing the reporting template and replacing it with a blank one
	// to prevent "carry over" from stale (previous) estimates
	NewModernReportingTemplate
	
	forvalues bc = 1/6 {

		global SubSet "tier1_leverage <50 & tier1_leverage>4 & IndDeNovo == 0 & flag == `2'"
		global controls "c_asset1 c_asset2 c_asset3"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// no time-fixed effects
		xtreg tier1_leverage i.top_size##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 2
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// time-fixed effects	
		xtreg tier1_leverage i.top_size##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_size#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 5
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		global SubSet "tier1_risk_based <50 & tier1_risk_based>4 & IndDeNovo == 0 & flag == `2'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// no time-fixed effects
		xtreg tier1_risk_based i.top_size##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 8
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// time-fixed effects
		xtreg tier1_risk_based i.top_size##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_size#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 11
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		global SubSet "total_risk_based <50 & total_risk_based>4 & IndDeNovo == 0 & flag == `2'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// no time-fixed effects	
		xtreg total_risk_based i.top_size##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 14
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// time-fixed effects
		xtreg total_risk_based i.top_size##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)		
		display "`e(cmdline)'"
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_size#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 17
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		global SubSet "eqt < 50 & eqt > 4 & IndDeNovo == 0 & flag == `2'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// no time-fixed effects
		xtreg eqt i.top_size##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 20
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"
		
		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Sample Size Cutoff: `3'"
		// time-fixed effects
		xtreg eqt i.top_size##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_size#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_size#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 23
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "`1'"

		
	}

	export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
	in 1/25 using "./output/tab_baseline.xlsx", sheet("mod cut `3' top `1'") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt
	
end

gen flag = 0
replace flag = 1 if assets >= 250000000
replace flag = 2 if assets >= 100000000
replace flag = 3 if assets >= 50000000
replace flag = 4 if assets >= 10000000

ModernRankBasedRegressions2 5 1 "250bn"

ModernSizeCutoffRegressions 250000000 "250bn"
ModernSizeCutoffRegressions 100000000 "100bn"
ModernSizeCutoffRegressions 50000000 "50bn"
ModernSizeCutoffRegressions 10000000 "10bn"



// END OF FILE //
