/*
filename: tab_8_mod_capital_by_deciles.do
*/


frames reset
use ./data/xt_mod_qq.dta, clear

/*
Generating indicator for DeNovo Banks
*/
tostring dt_open, g(dt_open_str) 
gen established = qofd(date(dt_open_str,"YMD"))
format established %tqCY_!Qq
gen age = (q_date-established)/4
order dt_open establishe* q_date age, first
gen IndDeNovo = cond(age<=5,1,0)
tab q_date IndDeNovo
// keeping only non-DeNovo Banks
keep if IndDeNovo == 0 
tab q_date IndDeNovo




summ eqt tier1_leverage_ratio total_risk_based_capital_ratio tier1_risk_based_capital_ratio, d
 
// ratios in percent rather than fraction
replace tier1_leverage_ratio = 100*tier1_leverage_ratio 
replace total_risk_based_capital_ratio = 100*total_risk_based_capital_ratio 
replace tier1_risk_based_capital_ratio = 100*tier1_risk_based_capital_ratio

summ eqt tier1_leverage_ratio total_risk_based_capital_ratio tier1_risk_based_capital_ratio, d

rename eqt EQTY
rename tier1_leverage_ratio T1LR
rename total_risk_based_capital_ratio TRBR
rename tier1_risk_based_capital_ratio T1RB

frames dir
frame copy default EQTY, replace
frame copy default T1LR, replace
frame copy default T1RB, replace
frame copy default TRBR, replace
frames dir

capture noisily program drop StatsByDeciles
program define StatsByDeciles
	
	frame change `1'

	keep if q_date < yq(2011,1)
	keep if q_date > yq(2000,4)
	
	// winsorizing
	gen flag = 0
	summ `1', d 
	replace flag = 1 if `1' > `r(p99)'
	replace flag = 2 if `1' < `r(p1)' 
	summ `1' if flag == 1, d
	summ `1' if flag == 2, d
	replace flag = cond(flag==0,0,1)
	tab q_date flag

	// checking whether winsorizing affected largest banks 
	tab flag size_cat
	drop if flag ==1
	drop flag

	egen decile_assets = xtile(assets), nq(10) by(q_date)

	collapse (mean) mn_`1' = `1' (sd) sd_`1' = `1', by(q_date decile_assets) 

end

StatsByDeciles EQTY
StatsByDeciles T1LR
StatsByDeciles TRBR
StatsByDeciles T1RB

frame change EQTY

frlink 1:1 q_date decile_assets, frame(T1LR) 
frlink 1:1 q_date decile_assets, frame(TRBR) 
frlink 1:1 q_date decile_assets, frame(T1RB) 

frget mn_T1LR sd_T1LR, from(T1LR)
frget mn_TRBR sd_TRBR, from(TRBR)
frget mn_T1RB sd_T1RB, from(T1RB)

drop T1LR T1RB TRBR

gen year = year(dofq(q_date))
gen quarter = quarter(dofq(q_date))
order year quarter q_date

export excel using ".\output\tab_modern_capitalization_by_date_by_size_decile.xlsx", sheetreplace firstrow(variables) keepcellfmt 

// END OF FILE // 
