/*
filename: tab_9_hist_assets_decomp.do
*/


clear
// running file that combines all four historical data sets
do ./code/dtm_combine_historical_banks.do

tab d_date
tab source if d_date==.

merge m:1 d_date using ./data/ts_business_cycles_on_unit_interval.dta

tab _merge

keep if _merge ==3
drop _merge
drop m_bc_*
drop if bank_id == .

replace year = year(d_date)
drop age*
gen age = year - organized
order cent_rank_in_call_id size_rank_in_call_id source call_id age 

gen loa_ass = (a_tot_loans/assets)*100
gen inv_ass = (a_tot_inv/assets)*100
gen cas_ass = (a_tot_cash/assets)*100
gen oth_ass = (a_tot_other/assets)*100

gen a_loa_sec_bon_ass = 100*(a_loans_sec_bond/assets)
gen a_loa_sec_oth_ass = 100*(a_loans_sec_other/assets) 
gen a_loa_not_sec_ass = 100*(a_loans_not_sec/assets)


gen sum_ass = loa_ass + inv_ass + cas_ass + oth_ass

sum sum_ass

gsort -sum_ass

order sum_ass loa_ass inv_ass cas_ass oth_ass



gen flag=0
replace flag = 1 if source == "nat_qa" & dbl_id>9000 &  (call_id == 3 | call_id == 7 | call_id == 11 | call_id == 15 | call_id == 19 | call_id == 23 | call_id == 26 | call_id == 31 | call_id == 35)

drop if flag==1


duplicates list bank_id call_id
duplicates list bank_id name call_id



drop if name == "BLANK"
drop if name == "NATIONAL BANK OF BAY RIDGE, BROOKLYN"
drop if name == "GLENS FALLS, FIRST"

xtset bank_id call_id

// ASSET PORTFOLIO DECOMPOSITION
gen c_assets1 = 100*(a_tot_loans/assets)
gen c_assets2 = 100*(a_tot_inv/assets)
gen c_assets3 = 100*(a_tot_cash/assets)
gen c_assets4 = 100*(a_tot_other/assets)

summ c_assets1, d
summ c_assets2, d
summ c_assets3, d
summ c_assets4, d

capture noisily log close _all
capture noisily log using ./output/log_9_portfolio_decomposition_regressions.log, text name(portfolio_decomposition) replace

global SubSet "age>5 & eqt <50"
global controls ""




foreach var in loa_ass inv_ass cas_ass a_loa_sec_bon_ass a_loa_sec_oth_ass a_loa_not_sec_ass {
	local bc = 2
		


		di "Business Cycle: `bc'"
		// time-fixed effects 
		xtreg `var' i.top10_size1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		testparm i.top10_size1929##c.h_bc_`bc' i.call_id ${controls}
		lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
		lincom 1.top10_size1929#c.h_bc_`bc', cformat(%9.2fc)  
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"

}
	
capture noisily log close portfolio_decomposition
	



// END OF FILE //
